==> joints-0.1.1-20181027.055904-1.jar: joints/components/datomic/conn.clj <==
(ns joints.components.datomic.conn
  (:require
   [com.stuartsierra.component :as c]
   [datomic.api :as d]
   [joints.components.datomic.proto :as cdp]
   [joints.components.util :as cu]))

(defrecord TempDatomicBlueprint [uri started?]
  c/Lifecycle
  (start [this]
    (if started?
      this
      (do (d/create-database uri)
          (assoc this :started? true))))
  (stop [this]
    (if-not started?
      this
      (assoc this :started? false))))

(defn make-temp-datomic-blueprint
  [uri]
  (map->TempDatomicBlueprint {:uri uri :started? false}))

(defrecord DatomicBlueprint [uri started?]
  c/Lifecycle
  (start [this]
    (if started?
      this
      (do (d/create-database uri)
          (assoc this :started? true))))
  (stop [this]
    (if-not started?
      this
      (do (d/delete-database uri)
          (assoc this :started? false)))))

(defn make-datomic-blueprint
  [uri]
  (map->DatomicBlueprint {:uri uri :started? false}))

(defn search-uri
  [m]
  (if-let [uri (->> (map val m)
                    (filter #(satisfies? cdp/IDatomicBlueprint %))
                    (map cdp/uri)
                    first)]
    uri
    (throw (ex-info "No datomic blueprint found" {}))))

(defrecord Datomic [conn]
  c/Lifecycle
  (start [this]
    (if (some? conn)
      this
      (let [conn (d/connect (search-uri this))]
        (assoc this :conn conn))))
  (stop [this]
    (if (nil? conn)
      this
      (do (d/release conn)
          (assoc this :conn nil)))))

(defn make-datomic
  []
  (map->Datomic {}))

==> joints-0.1.3-20181027.164643-1.jar: joints/components/datomic/conn.clj <==
(ns joints.components.datomic.conn
  (:require
   [com.stuartsierra.component :as c]
   [datomic.api :as d]
   [joints.components.datomic.proto :as cdp]))

(defrecord TempDatomicBlueprint [uri started?]
  c/Lifecycle
  (start [this]
    (if started?
      this
      (do (d/create-database uri)
          (assoc this :started? true))))
  (stop [this]
    (if-not started?
      this
      (assoc this :started? false))))

(defn make-temp-datomic-blueprint
  [uri]
  (map->TempDatomicBlueprint {:uri uri :started? false}))

(defrecord DatomicBlueprint [uri started?]
  c/Lifecycle
  (start [this]
    (if started?
      this
      (do (d/create-database uri)
          (assoc this :started? true))))
  (stop [this]
    (if-not started?
      this
      (do (d/delete-database uri)
          (assoc this :started? false)))))

(defn make-datomic-blueprint
  [uri]
  (map->DatomicBlueprint {:uri uri :started? false}))

(defn search-uri
  [m]
  (if-let [uri (->> m
                    (map val)
                    (filter #(satisfies? cdp/IDatomicBlueprint %))
                    (map cdp/uri)
                    first)]
    uri
    (throw (ex-info "No datomic blueprint found" {}))))

(defrecord Datomic [conn]
  c/Lifecycle
  (start [this]
    (if (some? conn)
      this
      (let [conn (d/connect (search-uri this))]
        (assoc this :conn conn))))
  (stop [this]
    (if (nil? conn)
      this
      (do (d/release conn)
          (assoc this :conn nil)))))

(defn make-datomic
  []
  (map->Datomic {}))
